/*
	Antenna House PDF Tool API V7.0
	C++ Interface sample program

	TvFy[W

	Copyright 2015-2021 Antenna House, Inc.
*/

#include <PdfTk.h>
#include <stdio.h>

using namespace PdfTk;

void removeLinkAction(PtlPage& page);

int main(int argc, char* argv[])
{
	if (argc < 4) {
		printf("usage: DividePage.exe in-pdf-file out-pdf-file \n\n");
		printf("\n0 : y[W㉺ɕ  1 : y[WEɕ\n");
		return 1;
	}
	try
	{
		PtlParamInput input(argv[1]);
		PtlParamOutput output(argv[2]);

		PtlPDFDocument doc;

		// PDFt@C[h܂B
		doc.load(input);

		// y[W̎擾
		int numPages = doc.getPageCount();
		printf("y[WF%d\n", numPages);

		// y[WRei̎擾
		PtlPages& pages = doc.getPages();
		if (pages.isEmpty()){
			printf("y[WRei\n");
			return 1;
		}

		const char* direction = argv[3];
		switch (direction[0]) {
		case '0':
		case '1':
			break;
		default:
			printf("usage: DividePage.exe in-pdf-file out-pdf-file \n\n");
			printf("\n0 : y[W㉺ɕ  1 : y[WEɕ\n");
			return 1;
		}

		// VKPDF
		PtlPDFDocument docNew;
		// y[WRei̎擾
		PtlPages& pagesNew = docNew.getPages();

		for (int i=0; i< numPages; ++i) {
			// ǂݍ񂾃y[W̎擾
			PtlPage page = pages.get(i);
			PtlSize size = page.getSize();
			float width = size.getWidth();
			float height = size.getHeight();
			// ǂݍ񂾃y[W̕\`擾
			PtlRect viewBox = page.getViewBox();

			// y[W𕪊Ă̂Œ߂LinkANV폜Ă
			removeLinkAction(page);

			// ǂݍ񂾃y[WVKPDF2y[Wǉ
			pagesNew.append(page, PtlPages::OPTION_NONE);
			pagesNew.append(page, PtlPages::OPTION_NONE);

			// ǉꂽy[W擾
			int numPagesNew = pagesNew.getCount();
			PtlPage pageNew1 = pagesNew.get(numPagesNew-2);
			PtlPage pageNew2 = pagesNew.get(numPagesNew-1);

			// ǉꂽy[Wɐݒ肷\`
			PtlRect rect1(viewBox);
			PtlRect rect2(viewBox);

			switch (direction[0]) {
			case '0':
				{
					// ̍
					float halfHeight = size.getHeight()/2;
					// `̏㔼
					rect1.setBottom(viewBox.getBottom()+halfHeight);
					// `̉
					rect2.setTop(viewBox.getTop()-halfHeight);
				}
				break;
			case '1':
				{
					// ̕
					float halfWidth = size.getWidth()/2;
					// `̍
					rect1.setRight(viewBox.getRight()-halfWidth);
					// `̉E
					rect2.setLeft(viewBox.getLeft()+halfWidth);
				}
				break;
			}
			// ǉꂽy[W̕\`ݒ
			pageNew1.setViewBox(rect1);
			pageNew2.setViewBox(rect2);
		}

		// t@Cɕۑ܂B
		docNew.save(output);

		printf("!\n");
	}
	catch (const PtlException &e)
	{
		fprintf(stderr, "Error code : %d\n %s\n", e.getErrorCode(), e.getErrorMessage().c_str());
		return 1;
	}	
	return 0;
}

void removeLinkAction(PtlPage& page)
{
	if (!page.hasAnnots()) {
		return;
	}
	PtlAnnots& annots = page.getAnnots() ;
	int numAnnots = annots.getCount();
	for(int i=0; i<numAnnots; ++i) {
		PtlAnnot& annot = annots.get(i);
		switch (annot.getType()) {
		case PtlAnnot::TYPE_LINK:
			{
				PtlAnnotLink& annotLink = (PtlAnnotLink&)annot;
				PtlAction& action = annotLink.getAction();
				switch (action.getType()) {
				case PtlAction::TYPE_GOTO:
					annotLink.removeAction();
					break;
				default:
					break;
				}
			}
			break;
		default:
			break;
		}
	}
}
