/*
	Antenna House PDF Tool API V7.0
	C++ Interface sample program

	TvFœK

	Copyright 2015-2021 Antenna House, Inc.
*/

#include <PdfTk.h>
#include <stdio.h>

using namespace PdfTk;

int main(int argc, char* argv[])
{
	if (argc < 3) {
		printf("usage: Optimize.exe in-pdf-file out-pdf-file\n");
		return 1;
	}
	try
	{
		PtlParamInput input(argv[1]);
		PtlParamOutput output(argv[2]);
		PtlPDFDocument doc;

		// PDFt@C[h܂B
		doc.load(input);

		// œKp[^[
		PtlParamOptimize paramOptimize;

		// 摜œKp[^[
		PtlParamOptimizeImage& paramOptimizeImage = paramOptimize.getParamOptimizeImage();

		// J[摜œKp[^[
		PtlParamOptimizeImageColor& paramOptimizeImageColor = paramOptimizeImage.getParamOptimizeImageColor();
			paramOptimizeImageColor.setSourcePPI(150);
			paramOptimizeImageColor.setTargetPPI(75);
			paramOptimizeImageColor.setDownSampling(PtlParamOptimizeImageDownSampling::DOWNSAMPLING_BICUBIC);
			paramOptimizeImageColor.setMinDownSamplingRate(0.65f);
			paramOptimizeImageColor.setCompress(PtlParamOptimizeImageColor::COMPRESS_AUTO);
			paramOptimizeImageColor.setQuality(PtlParamOptimizeImageColor::QUALITY_MIDDLE);

		// O[XP[摜œKp[^[
		PtlParamOptimizeImageGrayScale paramOptimizeImageGrayScale = paramOptimizeImage.getParamOptimizeImageGrayScale();
			paramOptimizeImageGrayScale.setSourcePPI(200);
			paramOptimizeImageGrayScale.setTargetPPI(150);
			paramOptimizeImageGrayScale.setDownSampling(PtlParamOptimizeImageDownSampling::DOWNSAMPLING_BICUBIC);
			paramOptimizeImageGrayScale.setMinDownSamplingRate(0.65f);
			paramOptimizeImageGrayScale.setCompress(PtlParamOptimizeImageGrayScale::COMPRESS_AUTO);
			paramOptimizeImageGrayScale.setQuality(PtlParamOptimizeImageGrayScale::QUALITY_MIDDLE);

		// mN摜œKp[^[
		PtlParamOptimizeImageMono paramOptimizeImageMono = paramOptimizeImage.getParamOptimizeImageMono();
			paramOptimizeImageMono.setSourcePPI(200);
			paramOptimizeImageMono.setTargetPPI(150);
			paramOptimizeImageMono.setDownSampling(PtlParamOptimizeImageDownSampling::DOWNSAMPLING_BICUBIC);
			paramOptimizeImageMono.setMinDownSamplingRate(0.65f);
			paramOptimizeImageMono.setCompress(PtlParamOptimizeImageMono::COMPRESS_AUTO);

		// œK摜̑ΏFilterݒ
		paramOptimizeImage.setValidFilter(PtlParamOptimizeImage::FILTER_ALL &~ PtlParamOptimizeImage::FILTER_JBIG2Decode);

		// 摜̃_ETvOsŒTvݒ
		paramOptimizeImage.setMinSampleSize(110);

		paramOptimize.setRemoveOpenAction(true);
		paramOptimize.setRemoveOutlines(true);
		paramOptimize.setRemoveAnnots(true);
		paramOptimize.setRemoveArticles(true);
		paramOptimize.setRemoveThumbnails(true);

		// œK
		doc.optimize(paramOptimize);

		// t@Cɕۑ܂B
		doc.save(output);

		printf("!\n");
	}
	catch (const PtlException &e)
	{
		fprintf(stderr, "Error code : %d\n %s\n", e.getErrorCode(), e.getErrorMessage().c_str());
	}	
	return 0;
}

