﻿/*
	Antenna House PDF Tool API V7.0
	C++ Interface sample program

	概要：Separation Color

	Copyright 2021 Antenna House,Inc.
*/

#include <PdfTk.h>

using namespace std;
using namespace PdfTk;

int main(int argc, char* argv[])
{
	if (argc != 3)
	{
		printf("usage: SeparationColor.exe in-pdf-file out-pdf-file \n");
		return 1;
	}
	try {
		PtlParamInput input(argv[1]);
		PtlParamOutput output(argv[2]);

		PtlPDFDocument doc;
		doc.load(input);

		PtlParamString separationName("colorName");

		float c = 0.0f;				//シアンの値。0.0から1.0までの値
		float m = 1.0f;				//マゼンタの値。0.0から1.0までの値
		float y = 1.0f;				//黄の値。0.0から1.0までの値
		float k = 0.0f;				//黒の値。0.0から1.0までの値
		float sepValue = 0.5f;		//0.0 ～ 1.0までの値

		PtlColorSpaceSeparation cs(separationName, c, m, y, k);
		PtlColorSeparation colorsp(cs, sepValue);

		PtlPages& pages = doc.getPages();
		int pageCnt = doc.getPageCount();
		PtlParamDrawShape shape;
		shape.setFillColor(colorsp);
		shape.setLineColor(colorsp);

		PtlPage page = pages.get(0);
		PtlContent& content = page.getContent();
		PtlRect rect(0.0f, 0.0f, 100.0f, 100.0f);
		//円形を描画
		content.drawCircle(rect, shape);
		doc.save(output);

	}
	catch (PtlException e)
	{
		fprintf(stderr, "Error code : %d\n %s\n", e.getErrorCode(), e.getErrorMessage().c_str());
		return -1;
	}
}

