﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：証明書セキュリティの設定

	Copyright 2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace EncryptPubSec
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 5)
            {
                Console.WriteLine("usage: Encrypt.exe in-pdf-file out-pdf-file 暗号化種類 証明書種類 証明書file [証明書パスワード(pfx)]\n");
                Console.WriteLine("暗号化種類\n0 : 128 bit RC4  1 : 128 bit AES  2 : 256 bit AES \n");
                Console.WriteLine("証明書種類\n0 : PKCS12(.pfx)  1 : X509(.cer) \n");
                return;
            }

            switch (args[2])
            {
            case "0":
            case "1":
            case "2":
                break;
            default:
                Console.WriteLine("usage: Encrypt.exe in-pdf-file out-pdf-file 暗号化種類 証明書種類 証明書file [証明書パスワード(pfx)]\n");
                Console.WriteLine("暗号化種類\n0 : 128 bit RC4  1 : 128 bit AES  2 : 256 bit AES \n");
                Console.WriteLine("証明書種類\n0 : PKCS12(.pfx)  1 : X509(.cer) \n");
                return;
            }

            switch (args[3])
            {
            case "0":
                if (args.Length < 6)
                {
                    Console.WriteLine("usage: Encrypt.exe in-pdf-file out-pdf-file 暗号化種類 証明書種類 証明書file [証明書パスワード(pfx)]\n");
                    Console.WriteLine("暗号化種類\n0 : 128 bit RC4  1 : 128 bit AES  2 : 256 bit AES \n");
                    Console.WriteLine("証明書種類\n0 : PKCS12(.pfx)  1 : X509(.cer) \n");
                    return;
                }
                break;
            case "1":
                break;
            default:
                Console.WriteLine("usage: Encrypt.exe in-pdf-file out-pdf-file 暗号化種類 証明書種類 証明書file [証明書パスワード(pfx)]\n");
                Console.WriteLine("暗号化種類\n0 : 128 bit RC4  1 : 128 bit AES  2 : 256 bit AES \n");
                Console.WriteLine("証明書種類\n0 : PKCS12(.pfx)  1 : X509(.cer) \n");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);
 
                    using (PtlParamInput inputCert = new PtlParamInput(args[4]))
                    {
                        // 公開セキュリティハンドラ
                        switch (args[2])
                        {
                        case "0":
                            // 128 bit RC4
                            using (PtlEncryptPubKey128RC4 enc = new PtlEncryptPubKey128RC4())
                            {
                                switch (args[3])
                                {
                                case "0":
                                    encryptPubKeyPKCS12(enc, inputCert, args[5]);
                                    break;
                                case "1":
                                     encryptPubKeyX509(enc, inputCert);
                                    break;
                                }
                                doc.setEncrypt(enc);
                            }
                            break;
                        case "1":
                            // 128 bit AES
                            using (PtlEncryptPubKey128AES enc = new PtlEncryptPubKey128AES())
                            {
                                switch (args[3])
                                {
                                case "0":
                                    encryptPubKeyPKCS12(enc, inputCert, args[5]);
                                    break;
                                case "1":
                                    encryptPubKeyX509(enc, inputCert);
                                    break;
                                }
                                doc.setEncrypt(enc);
                            }
                            break;
                        case "2":
                            // 256 bit AES
                            using (PtlEncryptPubKey256AES enc = new PtlEncryptPubKey256AES())
                            {
                                switch (args[3])
                                {
                                case "0":
                                    encryptPubKeyPKCS12(enc, inputCert, args[5]);
                                    break;
                                case "1":
                                    encryptPubKeyX509(enc, inputCert);
                                    break;
                                }
                                doc.setEncrypt(enc);
                            }
                            break;
                        default:
                            break;
                        }
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }

        }

        static void encryptPubKeyPKCS12(PtlEncryptPubKey enc, PtlParamInput inputPfx, string password)
        {
            // 文書の全てのコンテンツを暗号化
            enc.setEncryptComponent(PtlEncrypt.ENCRYPT_COMPONENT.ENCRYPT_ALL);

            using (PtlRecipients recipients = enc.getRecipients())
            using (PtlRecipient recipient = new PtlRecipient())
            {
                recipient.setPKCS12(inputPfx, password);
                // 権限設定
                setPubKey(recipient);

                recipients.append(recipient);
            }
        }

        static void encryptPubKeyX509(PtlEncryptPubKey enc, PtlParamInput inputCer)
        {
            // 文書の全てのコンテンツを暗号化
            enc.setEncryptComponent(PtlEncrypt.ENCRYPT_COMPONENT.ENCRYPT_ALL);

            using (PtlRecipients recipients = enc.getRecipients())
            using (PtlRecipient recipient = new PtlRecipient())
            {
                recipient.setX509(inputCer);
                // 権限設定
                setPubKey(recipient);

                recipients.append(recipient);
            }
        }

        static void setPubKey(PtlRecipient recipient)
        {
            using (PtlEncryptPermissionPubKey typ = new PtlEncryptPermissionPubKey())
            {
                // 印刷権限の設定
                // PERM_PRINT_LOW = 1, /* 低解像度 */
                typ.setPrint(PtlEncryptPermissionType2.PERMISSION_PRINT.PERM_PRINT_LOW);

                // 変更権限の設定
                // PERM_MODIFY_ASSEMBLEDOC = 1, /* ページの挿入、削除、回転 */
                typ.setModify(PtlEncryptPermissionType2.PERMISSION_MODIFY.PERM_MODIFY_ASSEMBLEDOC);

                // テキスト、画像、その他の内容のコピーを有効にするかどうかの設定
                // false: 有効にしない
                typ.setCopy(false);

                // スクリーンリーダーデバイスのテキストアクセスを有効にするかどうかの設定
                // true: 有効にする
                typ.setAccessibility(true);

                // ユーザアクセス許可フラグの設定
                recipient.setPermission(typ);
            }
        }

    }
}
