﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：フォームデータのXFDFからのインポート

	Copyright 2021 Antenna House,Inc.
*/

using System;
using PdfTkNet;

namespace ImportFormDataXFDF
{
    class ImportFormDataXFDF
    {
        static void Main(string[] args)
        {
            if (args.Length < 3)
            {
                Console.WriteLine("usage: ImportFormDataXFDF.exe in-pdf-file out-pdf-file in-xfdf-file");
                return;
            }
            try
            {
                using (PtlParamInput input = new PtlParamInput(args[0]))
                using (PtlParamOutput output = new PtlParamOutput(args[1]))
                using (PtlParamInput inputXFDF = new PtlParamInput(args[2]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(input);
                    doc.importFormFieldsFromXFDF(inputXFDF);    //フォームフィールドデータのXFDF文書からのインポート
                    doc.save(output);
                    Console.WriteLine("-- 完了 --");
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
        }
    }
}
