﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：最適化

	Copyright 2015-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace Optimize
{
    class Program
    {
        static void Main(string[] args)
        {
             if (args.Length < 2)
            {
                Console.WriteLine("usage: Optimize.exe in-pdf-file out-pdf-file");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                using (PtlParamOptimize paramOptimize = new PtlParamOptimize())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    // 画像最適化パラメーターの取得
                    using (PtlParamOptimizeImage paramOptimizeImage = paramOptimize.getParamOptimizeImage())
                    // カラー画像最適化パラメーターの取得
                    using (PtlParamOptimizeImageColor paramOptimizeImageColor = paramOptimizeImage.getParamOptimizeImageColor())
                    // グレースケール画像最適化パラメーターの取得
                    using (PtlParamOptimizeImageGrayScale paramOptimizeImageGrayScale = paramOptimizeImage.getParamOptimizeImageGrayScale())
                    // モノクロ画像最適化パラメーターの取得
                    using (PtlParamOptimizeImageMono paramOptimizeImageMono = paramOptimizeImage.getParamOptimizeImageMono())
                    {
                        paramOptimizeImageColor.setSourcePPI(150);
                        paramOptimizeImageColor.setTargetPPI(75);
                        paramOptimizeImageColor.setDownSampling(PtlParamOptimizeImageDownSampling.DOWNSAMPLING_TYPE.DOWNSAMPLING_BICUBIC);
                        paramOptimizeImageColor.setMinDownSamplingRate(0.65f);
                        paramOptimizeImageColor.setCompress(PtlParamOptimizeImageColor.COMPRESS_TYPE.COMPRESS_AUTO);
                        paramOptimizeImageColor.setQuality(PtlParamOptimizeImageColor.QUALITY_TYPE.QUALITY_MIDDLE);

                        paramOptimizeImageGrayScale.setSourcePPI(200);
                        paramOptimizeImageGrayScale.setTargetPPI(150);
                        paramOptimizeImageGrayScale.setDownSampling(PtlParamOptimizeImageDownSampling.DOWNSAMPLING_TYPE.DOWNSAMPLING_BICUBIC);
                        paramOptimizeImageGrayScale.setMinDownSamplingRate(0.65f);
                        paramOptimizeImageGrayScale.setCompress(PtlParamOptimizeImageGrayScale.COMPRESS_TYPE.COMPRESS_AUTO);
                        paramOptimizeImageGrayScale.setQuality(PtlParamOptimizeImageGrayScale.QUALITY_TYPE.QUALITY_MIDDLE);

                        paramOptimizeImageMono.setSourcePPI(200);
                        paramOptimizeImageMono.setTargetPPI(150);
                        paramOptimizeImageMono.setDownSampling(PtlParamOptimizeImageDownSampling.DOWNSAMPLING_TYPE.DOWNSAMPLING_BICUBIC);
                        paramOptimizeImageMono.setMinDownSamplingRate(0.65f);
                        paramOptimizeImageMono.setCompress(PtlParamOptimizeImageMono.COMPRESS_TYPE.COMPRESS_AUTO);

                        // 最適化する画像の対象Filterを設定
                        paramOptimizeImage.setValidFilter(PtlParamOptimizeImage.FILTER_TYPE.FILTER_ALL & ~PtlParamOptimizeImage.FILTER_TYPE.FILTER_JBIG2Decode);

                        // 画像のダウンサンプリングを行う最低サンプル数を設定
                        paramOptimizeImage.setMinSampleSize(110);

                        paramOptimize.setRemoveOpenAction(true);
                        paramOptimize.setRemoveOutlines(true);
                        paramOptimize.setRemoveAnnots(true);
                        paramOptimize.setRemoveArticles(true);
                        paramOptimize.setRemoveThumbnails(true);

                        // 最適化
                        doc.optimize(paramOptimize);
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
