﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：添付ファイルの書き出し

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace OutputEmbeddedFile
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 2)
            {
                Console.WriteLine("usage: OutputEmbeddedFile.exe in-pdf-file out-pdf-file");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput writefile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    // 添付ファイルコンテナの取得
                    PtlEmbeddedFiles embeddedfiles = doc.getEmbeddedFiles();

                    // 添付ファイルコンテナが空かどうか
                    if (embeddedfiles.isEmpty())
                    {
                        Console.WriteLine("添付ファイルコンテナが空");
                        return;
                    }

                    // 添付ファイル数の取得
                    Console.WriteLine("添付ファイル数 : " + embeddedfiles.getCount());

                    // １番目の添付ファイルの取得
                    using (PtlEmbeddedFile embeddedfile = embeddedfiles.get(0))
                    {
                        Console.WriteLine("１番目の添付ファイル名 : " + embeddedfile.getFileName());

                        // １番目の添付ファイルの書き出し
                        Console.WriteLine("１番目の添付ファイルの書き出し...");
                        embeddedfile.writeFile(writefile);
                    }
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
