﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：しおりの削除

			このサンプルでは下記を行います。
			・第一階層の最初のしおりのアクションを削除
			・第一階層の2番目のしおりの子しおりを全てを削除
			・第一階層の3番目のしおり及びその子しおりを全てを削除

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace RemoveOutline
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 2)
            {
                Console.WriteLine("usage: RemoveOutline.exe in-pdf-file out-pdf-file");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    //PDFファイルをロードします。
                    doc.load(inputFile);

                    //アウトラインを持っているかどうか
                    if (!doc.hasOutlines())
                    {
                        Console.WriteLine("アウトラインを持っていない\n");
                        return;
                    }

                    //ルートアウトラインの取得
                    using (PtlOutline rootOutline = doc.getRootOutline())
                    {
                        if (rootOutline.hasChild()) {
                            //最初の子アウトラインの取得
                            using (PtlOutline outline = rootOutline.getFirstChild())
                            {
                                removeOutline(outline);
                            }
                        }
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }

        static void removeOutline(PtlOutline item)
        {
            Console.WriteLine("- " + item.getTitle());

            //アクションの削除
            Console.WriteLine("「" + item.getTitle() + "」のアクションを削除...");
            item.removeAction();

            //次の兄弟アウトラインの取得
            try
            {
                using (PtlOutline item2 = item.getNextSibling())
                {
                    Console.WriteLine("- " + item2.getTitle());

                    //子アウトラインの削除
                    Console.WriteLine("「" + item2.getTitle() + "」の子しおりを削除...");
                    item2.removeChildren();

                    //次の兄弟アウトラインの取得
                    using (PtlOutline item3 = item2.getNextSibling())
                    {
                        Console.WriteLine("- " + item3.getTitle());
                        //自分自身及び子アウトラインの削除
                        Console.WriteLine("「" + item3.getTitle() + "」と子しおりを削除...");
                        item3.destroy();
                    }
                }
            }
            catch (PtlException pex)
            {
                if (pex.getErrorCode() != (int)PtlErrorCode.ERROR_CODE.NO_OBJECT)
                {
                    Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                }
            }
        }
    }
}
