﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：テキスト検索して文字列をパスで囲む

	Copyright 2018-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace SearchTextAndDrawPath
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 3)
            {
                Console.WriteLine("usage: SearchTextAndDrawPath.exe in-pdf-file out-pdf-file keyword");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    // ページコンテナの取得
                    using (PtlPages pages = doc.getPages())
                    {
                        // ページコンテナが空かどうか
                        if (pages.isEmpty())
                        {
                            Console.WriteLine("ページコンテナが空");
                            return;
                        }
                        using (PtlParamSearchText paramSearchText = new PtlParamSearchText())  // 検索の為のパラメータ
                        using (PtlParamDrawShape paramDrawShape = new PtlParamDrawShape())
                        using (PtlColorDeviceRGB colorRed = new PtlColorDeviceRGB(1.0f, 0.0f, 0.0f))
                        using (PtlColorDeviceRGB colorBlue = new PtlColorDeviceRGB(0.0f, 0.0f, 1.0f))
                        {
                            // 検索設定
                            paramSearchText.appendText(args[2]);

                            // 線の太さ
                            paramDrawShape.setLineWidth(1);

                            // 検索実行して検索結果コンテナ取得
                            using (PtlSearchTextResults results = doc.searchText(paramSearchText))
                            {
                                int numResults = results.getCount();
                                for (int i = 0; i < numResults; ++i)
                                {
                                    // 検索結果取得
                                    using (PtlSearchTextResult result = results.get(i))
                                    {
                                        // 検索に使用したキーワード
                                        String keyword = result.getKeyword();
                                        // ヒットしたページ番号
                                        int pageNumber = result.getPageNumber();
                                        using (PtlPage page = pages.get(pageNumber))
                                        using (PtlContent constent = page.getContent())
                                        {
                                            // 検索結果詳細コンテナ取得
                                            using (PtlSearchTextResultDetails details = result.getResultDetails())
                                            {
                                                int numDetails = details.getCount();
                                                for (int j = 0; j < numDetails; ++j)
                                                {
                                                    // 検索結果詳細取得
                                                    using (PtlSearchTextResultDetail resultDetail = details.get(j))
                                                    {
                                                        // 検索に使用したキーワードの部分文字列
                                                        String keywordD = resultDetail.getKeyword();
                                                        // 検索に使用したキーワードの部分文字列を囲むQuadPoint
                                                        using (PtlQuadPoint quad = resultDetail.getQuadPoint())
                                                        {
                                                            using (PtlPoint tl = quad.getTopLeft())
                                                            using (PtlPoint tr = quad.getTopRight())
                                                            using (PtlPoint bl = quad.getBottomLeft())
                                                            using (PtlPoint br = quad.getBottomRight())
                                                            {
                                                                // 文字列をパスで囲む
                                                                paramDrawShape.setLineColor(colorBlue);
                                                                constent.drawLine(bl, tl, paramDrawShape);
                                                                constent.drawLine(tl, tr, paramDrawShape);
                                                                constent.drawLine(tr, br, paramDrawShape);
                                                                // ベースライン側は赤で書く
                                                                paramDrawShape.setLineColor(colorRed);
                                                                constent.drawLine(br, bl, paramDrawShape);
                                                            }
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
