﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：テキスト検索してマスク処理

	Copyright 2018-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace SearchTextAndMaskAuto
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 3)
            {
                Console.WriteLine("usage: SearchTextAndMaskAuto.exe in-pdf-file out-pdf-file keyword");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    using (PtlParamSearchTextAndSetMask paramSearchText = new PtlParamSearchTextAndSetMask())  // 検索の為のパラメータ
                    using (PtlColorDeviceRGB color = new PtlColorDeviceRGB(1.0f, 0.0f, 0.0f))
                    {
                        // 検索設定
                        paramSearchText.appendText(args[2]);
                        paramSearchText.setColor(color);
                        paramSearchText.setOpacity(0.5f);

                        // 検索実行
                        doc.searchTextAndDoProcess(paramSearchText);
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
