﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：開き方の設定

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace SetOpenMode
{
    class Program
    {
        static void Main(string[] args)
        {
             if (args.Length < 2)
            {
                Console.WriteLine("usage: SetOpenMode.exe in-pdf-file out-pdf-file");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    // 文書プロパティの取得
                    using (PtlDocProperty docproperty = doc.getDocProperty())
                    {
                        // 開き方の取得
                        using (PtlOpenMode openmode = docproperty.getOpenMode())
                        {
                            // ページモードの設定 PAGE_MODE_USE_THUMBS = 3 /* サムネイルパネルとページ */
                            openmode.setPageMode(PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_THUMBS);

                            // ページレイアウトの設定 PAGE_LAYOUT_ONE_COLUMN = 2 /* 連続ページ */
                            openmode.setPageLayout(PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_ONE_COLUMN);

                            // オープンアクションの設定
                            using (PtlActionGoTo act = new PtlActionGoTo())
                            using (PtlDestFitR dst = new PtlDestFitR())    //PDFの宛先
                            {
                                // 宛先ページの設定(ページ番号は0ベース)
                                dst.setPageNumber(1);
                                // leftの設定
                                dst.setLeft(100.0f);
                                //dst.setLeftNull();
                                // bottomの設定
                                dst.setBottom(100.0f);
                                //dst.setBottomNull();
                                // rightの設定
                                dst.setRight(120.0f);
                                //dst.setRightNull();
                                // topの設定
                                dst.setTop(150.0f);
                                //dst.setTopNull();
                                // zoomの設定
                                dst.setZoom(100.0f);
                                //dst.setZoomNull();
                                act.setDest(dst);
                                openmode.setOpenAction(act);
                            }

                            // ウインドウオプションを設定（論理和）
                            // WINDOWS_OPTION_FIT_WINDOW = 0x00000001,		/* ページにウィンドウサイズを合あわせる */
                            // WINDOWS_OPTION_CENTER_WINDOW = 0x00000002,	/* ウィンドウを画面中央に配置 */
                            openmode.setWindowOption(PtlOpenMode.WINDOWS_OPTION.WINDOWS_OPTION_FIT_WINDOW
                                | PtlOpenMode.WINDOWS_OPTION.WINDOWS_OPTION_CENTER_WINDOW);

                            // ウィンドウのタイトルバーに文書タイトルを表示するかどうか設定（true: 非表示、false: 表示）
                            openmode.setDisplayDocTitle(true);

                            // ユーザーインターフェイスオプションを設定（論理和）
                            // UI_OPTION_HIDE_WINDOWUI = 0x00000004		/* ウインドウコントロールを非表示 */
                            openmode.setUIOption(PtlOpenMode.UI_OPTION.UI_OPTION_HIDE_WINDOWUI);
                        }
                        // 読み上げオプション設定 DIRECTION_R2L = 2 /* 右から左(中国語、日本語、韓国語のような縦書きも含む)	*/
                        docproperty.setDirection(PtlDocProperty.DIRECTION.DIRECTION_R2L);
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
