/*
	Antenna House PDF Tool API V7.0
	Java Interface sample program

	概要：テキストボックス

	Copyright 2021 Antenna House,Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class DrawTextBox {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 2)
        {
            System.out.println("usage: java DrawTextBox in-pdf-file out-pdf-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument();
             PtlOption option = new PtlOption())
        {
            option.setUnit(PtlOption.UNIT.UNIT_PT);

            doc.load(inputFile);

            String fontName = "メイリオ";
            float fontSize = 12.0f;

            try (PtlParamFont fontNormal = new PtlParamFont(fontName, fontSize, false, false, true);
                 PtlParamFont fontBoldItalic = new PtlParamFont(fontName, fontSize, true, true, true);
                 PtlColorDeviceRGB colorBlack = new PtlColorDeviceRGB(0.0f, 0.0f, 0.0f);
                 PtlColorDeviceRGB colorRed = new PtlColorDeviceRGB(1.0f, 0.0f, 0.0f);
                 PtlColorDeviceRGB colorBlue = new PtlColorDeviceRGB(0.0f, 0.0f, 1.0f);
                 PtlColorDeviceRGB colorBack = new PtlColorDeviceRGB(0.5f, 0.8f, 0.8f);
                 PtlColorDeviceRGB colorBack2 = new PtlColorDeviceRGB(0.8f, 0.5f, 0.8f))
            {
                try (PtlPages pages = doc.getPages();
                     PtlPage page = pages.get(0);     //1ページ目
                     PtlSize pageSize = page.getSize();
                     PtlContent content = page.getContent();
                     PtlRect rect = new PtlRect(20, 20, pageSize.getWidth() - 20, pageSize.getHeight() - 20))
                {
                    try (PtlParamWriteStringTextBox paramWriteString = new PtlParamWriteStringTextBox();
                         PtlParamWriteStringTextBox paramWriteStringBoldItalic = new PtlParamWriteStringTextBox();
                         PtlParamWriteStringTextBox paramWriteStringColor = new PtlParamWriteStringTextBox();
                         PtlParamWriteStringTextBox paramWriteString5 = new PtlParamWriteStringTextBox();
                         PtlParamWriteStringTextBox paramWriteString6 = new PtlParamWriteStringTextBox();
                         PtlParamWriteStringTextBox paramWriteString7 = new PtlParamWriteStringTextBox();
                         PtlParamWriteStringTextBox paramWriteString8 = new PtlParamWriteStringTextBox();
                         PtlParamWriteStringTextBox paramWriteString8Sup = new PtlParamWriteStringTextBox();
                         PtlParamWriteStringTextBox paramWriteString8Sub = new PtlParamWriteStringTextBox();
                         PtlTextBox textBox = content.drawTextBox(rect, PtlContent.ALIGN.ALIGN_TOP_LEFT, 300, 400))
                    {
                        // TextBoxの縁取りを付ける
                        textBox.setOutlineColor(colorRed);

                        // 縁取りがテキストを囲むサイズに変わるよう指定
                        textBox.fitToBBox(true);

                        paramWriteString.setFont(fontNormal);
                        paramWriteString.setTextColor(colorBlack);

                        String text1 = "長いテキストは折り返されます。あああああいいいいいうううううえええええおおおおお。";
                        textBox.writeStringNL(text1, paramWriteString);

                        String text2 = ("英字は途中で折り返されません。TextBoxはPtlParamWriteStringTextBoxを使います。");
                        textBox.writeStringNL(text2, paramWriteString);

                        textBox.writeNL();
                        paramWriteString.setUnderline(true);
                        paramWriteString.setStrikeOut(true);
                        String text3 = ("下線と取り消し線はPtlParamWriteStringTextBoxで指定して書くことができます。");
                        textBox.writeString(text3, paramWriteString);
                        paramWriteString.setUnderline(false);
                        paramWriteString.setStrikeOut(false);

                        paramWriteStringBoldItalic.setFont(fontBoldItalic);
                        String text4 = ("太字、斜体のフォントスタイルはPtlParamFontで設定します。");
                        textBox.writeStringNL(text4, paramWriteStringBoldItalic);

                        textBox.writeNL();
                        fontNormal.setFontSize(24);
                        paramWriteStringColor.setFont(fontNormal);
                        paramWriteStringColor.setTextColor(colorRed);
                        paramWriteStringColor.setBackColor(colorBack);
                        String text41 = ("フォントサイズを24にして文字の色をかえてみます。");
                        textBox.writeStringNL(text41, paramWriteStringColor);
                        paramWriteStringColor.setTextColor(colorBack);
                        paramWriteStringColor.setOutlineColor(colorBlack);
                        paramWriteStringColor.setBackColor(colorBack2);
                        String text42 = ("文字の縁取りの色をかえてみます。");
                        textBox.writeStringNL(text42, paramWriteStringColor);
                        fontNormal.setFontSize(12);

                        textBox.writeNL(12);    // そのまま改行すると、24で改行されるので12にする
                        String text52 = ("上付き文字");
                    	paramWriteString5.setFont(fontNormal);
                        paramWriteString5.setFormat(PtlParamWriteStringTextBox.FORMAT_TYPE.FORM_SUP);
                        paramWriteString5.setBackColor(colorBack2);
                        paramWriteString5.setUnderline(true);
                        paramWriteString5.setStrikeOut(true);
                        textBox.writeString(text52, paramWriteString5);
                        String text53 = ("と");
                        paramWriteString5.setFormat(PtlParamWriteStringTextBox.FORMAT_TYPE.FORM_NORMAL);
                        paramWriteString5.setBackColor(colorBack);
                        textBox.writeString(text53, paramWriteString5);
                        String text54 = ("下付き文字。");
                        paramWriteString5.setBackColor(colorBack2);
                        paramWriteString5.setFormat(PtlParamWriteStringTextBox.FORMAT_TYPE.FORM_SUB);
                        textBox.writeString(text54, paramWriteString5);
                        String text55 = ("通常文字。");
                        paramWriteString5.setFormat(PtlParamWriteStringTextBox.FORMAT_TYPE.FORM_NORMAL);
                        paramWriteString5.setBackColor(colorBack);
                        textBox.writeString(text55, paramWriteString5);

                        String text6 = ("行間を広くして書いてみます。");
                        paramWriteString6.setFont(fontNormal);
                        paramWriteString6.setBackColor(colorBack2);
                        paramWriteString6.setLineSpacing(1.5f);
                        textBox.writeStringNL(text6, paramWriteString6);

                        textBox.writeNL();
                        String text7 = ("文字間隔をかえてみます。");
                        paramWriteString7.setFont(fontNormal);
                        paramWriteString7.setBackColor(colorBack);
                        textBox.writeStringNL(text7, paramWriteString7);
                        String text72 = ("文字間隔狭い(-1)。");
                        paramWriteString7.setCharSpacing(-1);
                        textBox.writeStringNL(text72, paramWriteString7);
                        String text73 = ("文字間隔広い(1)。");
                        paramWriteString7.setCharSpacing(1);
                        textBox.writeStringNL(text73, paramWriteString7);
                        String text74 = ("文字間隔広い(2)。");
                        paramWriteString7.setCharSpacing(2);
                        paramWriteString7.setUnderline(true);
                        paramWriteString7.setStrikeOut(true);
                        textBox.writeStringNL(text74, paramWriteString7);


                        textBox.writeNL();
                        paramWriteString8.setFont(fontNormal);
                        String text8 = ("化学式を上付き文字と下付き文字を使って書いてみます。");
                        textBox.writeStringNL(text8, paramWriteString8);
                    	paramWriteString8Sup.setFont(fontNormal);
                        paramWriteString8Sup.setFormat(PtlParamWriteStringTextBox.FORMAT_TYPE.FORM_SUP);
                    	paramWriteString8Sub.setFont(fontNormal);
                        paramWriteString8Sub.setFormat(PtlParamWriteStringTextBox.FORMAT_TYPE.FORM_SUB);

                        // C4H8O2
                        String C4H8O2_C = ("C");
                        textBox.writeString(C4H8O2_C, paramWriteString8);
                        String C4H8O2_4 = ("4");
                        textBox.writeString(C4H8O2_4, paramWriteString8Sub);
                        String C4H8O2_H = ("H");
                        textBox.writeString(C4H8O2_H, paramWriteString8);
                        String C4H8O2_8 = ("8");
                        textBox.writeString(C4H8O2_8, paramWriteString8Sub);
                        String C4H8O2_O = ("O");
                        textBox.writeString(C4H8O2_O, paramWriteString8);
                        String C4H8O2_2 = ("2");
                        textBox.writeStringNL(C4H8O2_2, paramWriteString8Sub);

                        // SO42-
                        String SO42__SO = ("SO");
                        textBox.writeString(SO42__SO, paramWriteString8);
                        String SO42__4 = ("4");
                        textBox.writeString(SO42__4, paramWriteString8Sub);
                        String SO42__2_ = ("2-");
                        textBox.writeString(SO42__2_, paramWriteString8Sup);

                        textBox.terminate();

                        doc.save(outputFile);
                    }

                }
            }
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
	}
}

