/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：画像ファイルのPDF化(ソフトマスク)

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class ImageToPdfSMask {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java ImageToPdfSMask image-file mask-file out-pdf-file");
            return;
        }

        try (PtlParamOutput outputFile = new PtlParamOutput(args[2]);
             PtlPDFDocument doc = new PtlPDFDocument();
             PtlPages pages = doc.getPages())  // ページコンテナの取得
        {
            try (PtlParamDrawImage paramDrawImage = new PtlParamDrawImage();  // 画像描画パラメータ
                 PtlParamInput inputImage = new PtlParamInput(args[0]);       // 画像ファイル
                 PtlParamInput inputMask = new PtlParamInput(args[1]);        // マスクファイル
                 PtlParamImagePage paramImagePage = new PtlParamImagePage())  // 画像ページパラメータ
            {
                // 画像描画パラメータに画像ファイルを設定
                paramDrawImage.setImageStream(inputImage);

                // ソフトマスク
                paramDrawImage.setMaskImageStream(inputMask, PtlParamDrawImage.MASK_TYPE.MASK_SOFT);

                // 画像ページパラメータに画像描画パラメータを設定
                paramImagePage.setImage(paramDrawImage);

                // 画像ページのサイズを画像サイズにあわせる
                paramImagePage.setPaperType(PtlParamImagePage.PAPER_TYPE.PAPER_IMAGE_SIZE);

                // ページコンテナに画像ページパラメータを追加
                pages.append(paramImagePage);
            }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
