/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：画像ファイルのPDF化と既存PDFへのページ追加

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class InsertImagePage {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java InsertImagePage in-pdf-file insert-image-file out-pdf-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[2]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロードします。
            doc.load(inputFile);

            try (PtlPages pages = doc.getPages()) // ページコンテナの取得
            {
                try (PtlParamDrawImage paramDrawImage = new PtlParamDrawImage();  // 画像描画パラメータ
                     PtlParamInput inputImage = new PtlParamInput(args[1]);       // 画像ファイル
                     PtlParamImagePage paramImagePage = new PtlParamImagePage())  // 画像ページパラメータ
                {
                    // 画像描画パラメータに画像ファイルを設定
                    paramDrawImage.setImageStream(inputImage);

                    // マルチTiffのページ番号の設定（Tiffファイルにのみ有効） 
                    // -1を設定すると全ページを挿入します。設定しない場合は、-1が設定されたとみなします
                    paramDrawImage.setImagePageNumber(0);

                    // 画像ページパラメータに画像描画パラメータを設定
                    paramImagePage.setImage(paramDrawImage);

                    // 画像ページのサイズをA4にする
                    paramImagePage.setPaperType(PtlParamImagePage.PAPER_TYPE.PAPER_A4);

                    // 画像を配置するときの余白の設定
                    paramImagePage.setMargin(20.0f, 15.0f, 20.0f, 15.0f);

                    // 画像の配置の設定 ALIGN_TOP_LEFT = 1, // 左上 
                    paramImagePage.setAlign(PtlParamImagePage.ALIGN.ALIGN_TOP_LEFT);

                    // ページコンテナに画像ページパラメータを追加
                    //pages.insert(4, paramImagePage);// 5P目
                    pages.append(paramImagePage);// 最終
                }
            }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
