/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：最適化

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class Optimize {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 2)
        {
            System.out.println("usage: java Optimize in-pdf-file out-pdf-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument();
             PtlParamOptimize paramOptimize = new PtlParamOptimize())
        {
            // PDFファイルをロードします。
            doc.load(inputFile);

            try (PtlParamOptimizeImage paramOptimizeImage = paramOptimize.getParamOptimizeImage();  // 画像最適化パラメーターの取得
                 PtlParamOptimizeImageColor paramOptimizeImageColor = paramOptimizeImage.getParamOptimizeImageColor();              // カラー画像最適化パラメーターの取得
                 PtlParamOptimizeImageGrayScale paramOptimizeImageGrayScale = paramOptimizeImage.getParamOptimizeImageGrayScale();  // グレースケール画像最適化パラメーターの取得
                 PtlParamOptimizeImageMono paramOptimizeImageMono = paramOptimizeImage.getParamOptimizeImageMono()) {               // モノクロ画像最適化パラメーターの取得

                paramOptimizeImageColor.setSourcePPI(150);
                paramOptimizeImageColor.setTargetPPI(75);
                paramOptimizeImageColor.setDownSampling(PtlParamOptimizeImageDownSampling.DOWNSAMPLING_TYPE.DOWNSAMPLING_BICUBIC);
                paramOptimizeImageColor.setMinDownSamplingRate(0.65f);
                paramOptimizeImageColor.setCompress(PtlParamOptimizeImageColor.COMPRESS_TYPE.COMPRESS_AUTO);
                paramOptimizeImageColor.setQuality(PtlParamOptimizeImageColor.QUALITY_TYPE.QUALITY_MIDDLE);

                paramOptimizeImageGrayScale.setSourcePPI(200);
                paramOptimizeImageGrayScale.setTargetPPI(150);
                paramOptimizeImageGrayScale.setDownSampling(PtlParamOptimizeImageDownSampling.DOWNSAMPLING_TYPE.DOWNSAMPLING_BICUBIC);
                paramOptimizeImageGrayScale.setMinDownSamplingRate(0.65f);
                paramOptimizeImageGrayScale.setCompress(PtlParamOptimizeImageGrayScale.COMPRESS_TYPE.COMPRESS_AUTO);
                paramOptimizeImageGrayScale.setQuality(PtlParamOptimizeImageGrayScale.QUALITY_TYPE.QUALITY_MIDDLE);

                paramOptimizeImageMono.setSourcePPI(200);
                paramOptimizeImageMono.setTargetPPI(150);
                paramOptimizeImageMono.setDownSampling(PtlParamOptimizeImageDownSampling.DOWNSAMPLING_TYPE.DOWNSAMPLING_BICUBIC);
                paramOptimizeImageMono.setMinDownSamplingRate(0.65f);
                paramOptimizeImageMono.setCompress(PtlParamOptimizeImageMono.COMPRESS_TYPE.COMPRESS_AUTO);

                // 最適化する画像の対象Filterを設定
                paramOptimizeImage.setValidFilter(PtlParamOptimizeImage.FILTER_ALL & ~PtlParamOptimizeImage.FILTER_JBIG2Decode);

                // 画像のダウンサンプリングを行う最低サンプル数を設定
                paramOptimizeImage.setMinSampleSize(110);

                paramOptimize.setRemoveOpenAction(true);
                paramOptimize.setRemoveOutlines(true);
                paramOptimize.setRemoveAnnots(true);
                paramOptimize.setRemoveArticles(true);
                paramOptimize.setRemoveThumbnails(true);

                // 最適化
                doc.optimize(paramOptimize);
            }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
