/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：注釈の削除

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import java.io.*;
import jp.co.antenna.ptl.*;

public class RemoveAnnots {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java RemoveAnnots in-pdf-file out-pdf-file 削除方法\n");
            System.out.println("削除方法\n0 : ひとつめの注釈の削除 1 : 全注釈の削除\n");
            return;
        }
        String kind = args[2];
        switch (kind) {
        case "0":
        case "1":
            break;
        default:
            System.out.println("usage: java RemoveAnnots in-pdf-file out-pdf-file 削除方法\n");
            System.out.println("削除方法\n0 : ひとつめの注釈の削除 1 : 全注釈の削除\n");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument()) {

            // PDFファイルをロードします。
            doc.load(inputFile);

            try (PtlPages pages = doc.getPages()) // ページコンテナの取得
            {
                // ページコンテナが空かどうか
                if (pages.isEmpty())
                {
                    System.out.println("ページコンテナが空\n");
                    return;
                }

                 try (PtlPage page = pages.get(0);         // 1ページ目の取得
                      PtlAnnots annots = page.getAnnots()) {

                    // 注釈コンテナが空かどうか
                    if (annots.isEmpty())
                    {
                        System.out.println("注釈なし");
                    }
                    else
                    {
                        // 注釈数の取得
                        int numAnnots = annots.getCount();
                        System.out.println("注釈数 : " + numAnnots);
                        if (numAnnots == 0) {
                            return;
                        }

                        switch (kind)
                        {
                        case "0":
                            // 注釈の削除
                            annots.remove(0);
                              break;
                        case "1":
                            // 全注釈の削除
                            annots.removeAll();
                            break;
                        }
                    }
                }
            }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }

}
