/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：ページ削除

        ※ パラメーターの指定で全ページの削除が出来ますが、全てのページを削除したらPDFとしてなりたたないのでエラーとなります。

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import java.io.*;
import jp.co.antenna.ptl.*;

public class RemovePages {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java RemovePages in-pdf-file out-pdf-file  削除方法\n");
            System.out.println("削除方法\n0 : １ページ目を削除  1 : ２-３ページを削除  2 : 全ページの削除\n");
            return;
        }
        String kind = args[2];
        switch (kind) {
        case "0":
        case "1":
        case "2":
            break;
        default:
            System.out.println("usage: java RemovePages in-pdf-file out-pdf-file  削除方法\n");
            System.out.println("削除方法\n0 : １ページ目を削除  1 : ２-３ページを削除  2 : 全ページの削除\n");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロードします。
            doc.load(inputFile);

            // リニアライズ
            doc.setSaveOption(PtlPDFDocument.SAVE_OPTION.SAVE_LINEARIZE);

            // ページ数の取得
            System.out.println("ページ数：" + doc.getPageCount());

            try (PtlPages pages = doc.getPages()) //ページコンテナの取得
            {
                // ページコンテナが空かどうか
                if (pages.isEmpty())
                {
                    System.out.println("ページコンテナが空\n");
                    return;
                }

                switch (kind)
                {
                case "0":
                    // １ページ目を削除
                    pages.remove(0);
                    break;
                case "1":
                    // 複数ページの削除
                    pages.remove(1, 2);
                    break;
                case "2":
                    // 全ページの削除
                    pages.removeAll(); // このままsaveするとエラーになります
                    break;
                }
            }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
