/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：テキスト検索してマスク処理

    Copyright 2018-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class SearchTextAndMaskAuto {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java SearchTextAndMaskAuto in-pdf-file out-pdf-file keyword");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロード
            doc.load(inputFile);

            try (PtlParamSearchTextAndSetMask paramSearchText = new PtlParamSearchTextAndSetMask();
                 PtlColorDeviceRGB color = new PtlColorDeviceRGB(1.0f, 0.0f, 0.0f))
            {
                // 検索設定
                paramSearchText.appendText(args[2]);
                paramSearchText.setColor(color);
                paramSearchText.setOpacity(0.5f);

                // 検索してマスク処理実行
                doc.searchTextAndDoProcess(paramSearchText);
            }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
