/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：文書情報の設定

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class SetDocInfo {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 2)
        {
            System.out.println("usage: java SetDocInfo in-pdf-file out-pdf-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロード
            doc.load(inputFile);

            try (PtlDocProperty docProperty = doc.getDocProperty(); // PDFの文書プロパティ
                 PtlDocInfo docinf = docProperty.getDocInfo()) {    // PDFの文書情報

                // タイトルを設定
                docinf.setTitle("タイトル");

                // 著者を設定
                docinf.setAuthor("作者");

                // サブジェクトを設定
                docinf.setSubject("サブジェクト");

                // キーワードを設定
                docinf.setKeywords("キーワード");

                // クリエータを設定
                docinf.setCreator("クリエイタ");

                // プロデューサを設定
                docinf.setProducer("プロデューサ");

                // 作成日付を設定（2014/1/3 9:00:00）
                try (PtlDate dateCreateNew = new PtlDate(2014,1,3,9,0,0))
                {
                    docinf.setCreationDate(dateCreateNew);
                }

                // 更新日付を設定（2014/3/10 23:15:50）
                try (PtlDate dateModNew = new PtlDate(2014,3,10,23,15,50))
                {
                    docinf.setModDate(dateModNew);
                }
            }

            // ファイルに保存します
            doc.save(outputFile);
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
